
/*************************************************
****    VEGA - Connectivity Generator V1.2    ****
**** Copyright 1996-2000, Alessandro Pedretti ****
*************************************************/


/* Element, mass, covalent radius and Van Der Waals radius */

#ifndef __CONNECT
#define  __CONNECT
const ATMTAB AtmTable[]        = {{{"H" }, 1.008, 0.37, 1.20},
                                  {{"C" }, 12.01, 0.77, 1.94},
                                  {{"N" }, 14.01, 0.75, 1.70},
                                  {{"O" }, 16.00, 0.73, 1.55},
                                  {{"S" }, 32.06, 1.02, 1.80},
                                  {{"P" }, 30.97, 1.10, 1.85},
                                  {{"F" }, 19.00, 0.71, 1.50},
                                  {{"Cl"}, 35.45, 0.99, 1.80},
                                  {{"Br"}, 79.90, 1.14, 1.14},
                                  {{"I" }, 126.9, 1.33, 2.00},

                                  {{"He"}, 4.003, 0.50, 1.80},
                                  {{"Li"}, 6.941, 1.34, 1.80},
                                  {{"Be"}, 9.012, 1.25, 1.82},
                                  {{"B" }, 10.81, 0.90, 1.98},
                                  {{"Ne"}, 20.18, 0.65, 1.55},
                                  {{"Na"}, 22.99, 1.54, 2.30},
                                  {{"Mg"}, 24.31, 1.45, 1.70},
                                  {{"Al"}, 26.98, 1.30, 1.74},
                                  {{"Si"}, 28.09, 1.18, 2.10},
                                  {{"Ar"}, 39.95, 0.95, 1.90},
                                  {{"K" }, 39.10, 1.96, 2.80},
                                  {{"Ca"}, 40.08, 1.74, 1.94},
                                  {{"Sc"}, 44.96, 1.44, 1.82},
                                  {{"Ti"}, 47.90, 1.32, 2.25},
                                  {{"V" }, 50.94, 1.25, 2.18},
                                  {{"Cr"}, 52.00, 1.27, 2.11},
                                  {{"Mn"}, 54.94, 1.43, 2.03},
                                  {{"Fe"}, 55.85, 1.22, 1.22},
                                  {{"Co"}, 58.93, 1.26, 1.26},
                                  {{"Ni"}, 58.71, 1.20, 1.61},
                                  {{"Cu"}, 63.55, 1.38, 1.41},
                                  {{"Zn"}, 65.37, 1.25, 1.40},
                                  {{"Ga"}, 69.72, 1.25, 1.26},
                                  {{"Ge"}, 72.60, 1.22, 1.22},
                                  {{"As"}, 74.92, 1.21, 1.20},
                                  {{"Se"}, 78.96, 1.17, 1.16},
                                  {{"Kr"}, 83.80, 1.11, 1.12},
                                  {{"Rb"}, 85.47, 2.16, 2.16},
                                  {{"Sr"}, 87.62, 1.91},
                                  {{"Y" }, 88.91, 1.62},
                                  {{"Zr"}, 91.22, 1.45},
                                  {{"Nb"}, 92.91, 1.34},
                                  {{"Mo"}, 95.94, 1.30},
                                  {{"Tc"}, 99.00, 1.27},
                                  {{"Ru"}, 101.1, 1.25},
                                  {{"Rh"}, 102.9, 1.25},
                                  {{"Pd"}, 106.4, 1.28},
                                  {{"Ag"}, 107.9, 1.34},
                                  {{"Cd"}, 112.4, 1.41},
                                  {{"In"}, 114.8, 1.50},
                                  {{"Sn"}, 118.7, 1.40},
                                  {{"Sb"}, 121.8, 1.39},
                                  {{"Te"}, 127.6, 1.37},
                                  {{"Xe"}, 131.3, 1.30},
                                  {{"Cs"}, 132.9, 2.35},
                                  {{"Ba"}, 137.3, 1.98},
                                  {{"La"}, 138.9, 1.69},
                                  {{"Ce"}, 140.1, 1.65},
                                  {{"Pr"}, 140.9, 1.65},
                                  {{"Nd"}, 144.2, 1.64},
                                  {{"Pm"}, 147.0, 1.63},
                                  {{"Sm"}, 150.4, 1.62},
                                  {{"Eu"}, 152.0, 1.85},
                                  {{"Gd"}, 157.3, 1.61},
                                  {{"Tb"}, 158.9, 1.59},
                                  {{"Dy"}, 162.5, 1.59},
                                  {{"Ho"}, 164.9, 1.58},
                                  {{"Er"}, 167.3, 1.57},
                                  {{"Tm"}, 168.9, 1.56},
                                  {{"Yb"}, 173.0, 1.56},
                                  {{"Lu"}, 175.0, 1.56},
                                  {{"Hf"}, 178.5, 1.44},
                                  {{"Ta"}, 180.9, 1.34},
                                  {{"W" }, 183.9, 1.30},
                                  {{"Re"}, 186.2, 1.28},
                                  {{"Os"}, 190.2, 1.26},
                                  {{"Ir"}, 192.2, 1.27},
                                  {{"Pt"}, 195.1, 1.30},
                                  {{"Au"}, 197.0, 1.34},
                                  {{"Hg"}, 200.6, 1.44},
                                  {{"Tl"}, 204.4, 1.55},
                                  {{"Pb"}, 207.2, 1.54},
                                  {{"Bi"}, 209.0, 1.51},
                                  {{"Po"}, 210.0, 1.46},
                                  {{"At"}, 210.0, 1.45},
                                  {{"Rn"}, 222.0, 1.45},
                                  {{"Fr"}, 223.0, 1.00},
                                  {{"Ra"}, 226.0, 1.00},
                                  {{"Ac"}, 227.0, 1.00},
                                  {{"Th"}, 232.0, 1.00},
                                  {{"Pa"}, 231.0, 1.00},
                                  {{"U" }, 238.0, 1.00},
                                  {{"Np"}, 237.0, 1.00},
                                  {{"Pu"}, 242.0, 1.00},
                                  {{"Am"}, 243.0, 1.00},
                                  {{"Cm"}, 248.0, 1.00},
                                  {{"Bk"}, 247.0, 1.00},
                                  {{"Cf"}, 251.0, 1.00},
                                  {{"Es"}, 254.0, 1.00},
                                  {{"Fm"}, 253.0, 1.00},
                                  {{"Md"}, 256.0, 1.00},
                                  {{"No"}, 254.0, 1.00},
                                  {{"Lw"}, 257.0, 1.00},

                                  {{"Du"}, 12.01, 0.77, 1.94},

                                  {{0,0 },  0.00, 0.00, 0.00}
                                 };

/**** Aminoacidic residue names ****/

const VG_QCHAR AAResTab[]      = { {"ALA" }, {"ARG" }, {"ASN" }, {"ASP" }, {"CYS" },
                                   {"GLU" }, {"GLN" }, {"GLY" }, {"HIS" }, {"ILE" },
                                   {"LEU" }, {"LYS" }, {"MET" }, {"PHE" }, {"PRO" },
                                   {"SER" }, {"THR" }, {"TRP" }, {"TYR" }, {"VAL" },
                                   {"ARG+"}, {"LYS+"}, {"ASP-"}, {"GLU-"}, {"CYH" },
                                   {"HI+" }, {""    }
                                 };

const VG_QCHAR AAEquivTab[]    = { {"AP-"}, {"ASP"},
                                   {"GL-"}, {"GLU"},
                                   {"AR+"}, {"ARG"},
                                   {"LY+"}, {"LYS"},
                                   {"CYH"}, {"CYS"},
                                   {"HI+"}, {"HIS"},
                                   {""   }, {""   }
                                 };

const char AATab[]          =    "ARNDCEQGHILKMFPSTWYVRKDECH";
#endif

