
/*************************************************
****               VEGA - Types               ****
**** Copyright 1996-2002, Alessandro Pedretti ****
*************************************************/


#ifndef  __VG_TYPES
#define  __VG_TYPES

#ifndef __STDIO_H
#  include <stdio.h>
#endif

#define  MAXBOND            6           /* Max bond order */


/****************************
****      Label types    ****
**** See ATOMO structure ****
****************************/

#define  VG_ATMLBL_NONE         0
#define  VG_ATMLBL_NAME         1
#define  VG_ATMLBL_ELEMENT      2
#define  VG_ATMLBL_NUMBER       3
#define  VG_ATMLBL_TYPE         4
#define  VG_ATMLBL_CHARGE       5


/****************************
****  Color definitions  ****
**** See ATOMO structure ****
****************************/

#define  VGCOL_NONE             0
#define  VGCOL_BLACK            1
#define  VGCOL_WHITE            2
#define  VGCOL_RED              3
#define  VGCOL_GREEN            4
#define  VGCOL_CYAN             5
#define  VGCOL_YELLOW           6
#define  VGCOL_FIREBIRCK        7
#define  VGCOL_MAGENTA          8
#define  VGCOL_PINK             9
#define  VGCOL_VIOLET          10
#define  VGCOL_GRAY            11
#define  VGCOL_ORANGE          12
#define  VGCOL_DARKGREEN       13
#define  VGCOL_BLUE            14
#define  VGCOL_DARKYELLOW      15
#define  VGCOL_BROWN           16
#define  VGCOL_SKYBLUE         17
#define  VGCOL_DARKGRAY        18
#define  VGCOL_GHOSTPINK       19
#define  VGCOL_GHOSTGREEN      20
#define  VGCOL_GHOSTBLUE       21
#define  VGCOL_GHOSTYELLOW     22
#define  VGCOL_GHOSTGRAY       23
#define  VGCOL_SAND            24

#define  VGCOL_NUM             24


/**************************
**** Boolean constants ****
**************************/

#ifndef FALSE
#  define  FALSE               0
#endif
#ifndef TRUE
#  define  TRUE                1
#endif


/****************************
**** VEGA specific types ****
****************************/

typedef unsigned short      VG_BOOL;
typedef char                VG_BYTE;
typedef unsigned char       VG_UBYTE;
typedef int                 VG_LONG;
typedef unsigned int        VG_ULONG;
typedef short               VG_WORD;
typedef unsigned short      VG_UWORD;

typedef union {
  char      C[2];
  VG_WORD   S;
} VG_DCHAR;

typedef union {
  char      C[4];
  VG_LONG   L;
} VG_QCHAR;


/**** ATOMO structure ****/

typedef struct __Atomo {
  struct __Atomo    *Ptr;           /* Address of next structure */
  VG_ULONG          Num;            /* Atom number               */
  VG_QCHAR          Name;           /* Atom name                 */
  VG_DCHAR          Elem;           /* Element                   */
  VG_WORD           Ring;           /* Ring indicator            */
  VG_QCHAR          ResName;        /* Residue name              */
  VG_QCHAR          ResSeq;         /* Number of residue         */
  float             x, y, z;        /* X, Y, Z coodinates        */
  float             Charge;         /* Atomic charge             */
  float             Rad;            /* Atomic radius             */
  VG_QCHAR          Pot;            /* Atom type (potential)     */
  void              *Reserved;      /* Reserved for future use   */
  struct __Atomo    *Conn[MAXBOND]; /* Connectivity matrix       */
  VG_UBYTE          Order[MAXBOND]; /* Bond order (not used yet) */
  VG_BYTE           NSost;          /* Number of bonded atoms    */
  VG_BYTE           Flags;          /* ATOMO/HETATM, TER         */
  VG_BYTE           ChainID;        /* Chain indicator           */
  VG_UBYTE          ColorID;        /* Color ID (OpenGL)         */
  VG_UBYTE          Label;          /* Label (OpenGL)            */
  VG_UBYTE          Active;         /* Active atom (OpenGL)      */
} ATOMO;


/**** Surface data structure ****/

typedef struct __vg_surface {
  struct __vg_surface   *Ptr;
  VG_ULONG              AtmNum;     /* Atom number                            */
  float                 x, y, z;    /* Coordinates (don't change the order of */
  float                 Val;        /* these two fields)                      */
  VG_UBYTE              Color[3];   /* Color vector                           */
} VG_SURFACE;
#endif
